@@ -89,7 +89,8 @@ class Geary(object):
     0.3330108
     >>> print round(c.p_norm,7)
     9.2e-05
-    >>>
+    >>> c.z_rand
+    -3.6489513837253944
     """
     def __init__(self, y, w, transformation="r", permutations=999):
         if not isinstance(w, weights.W):
@@ -149,14 +150,15 @@ class Geary(object):
         s1 = w.s1
         s2 = w.s2
         s02 = s0 * s0
-
         yd = y - y.mean()
-        k = (1 / (sum(yd ** 4)) * ((sum(yd ** 2)) ** 2))
-        vc_rand = (1 / (n * ((n - 2) ** 2) * s02)) * \
-            ((((n - 1) * s1) * (n * n - 3 * n + 3 - (n - 1) * k))
-             - ((.25 * (n - 1) * s2) * (n * n + 3 * n - 6 -
-                (n * n - n + 2) * k))
-                + (s02 * (n * n - 3 - ((n - 1) ** 2) * k)))
+        yd4 = yd**4
+        yd2 = yd**2
+        n2 = n * n
+        k = (yd4.sum() / n) / ((yd2.sum()/n)**2)
+        A = (n-1) * s1 * (n2 - 3*n + 3 - (n-1) * k)
+        B = (1./4) * ((n-1) * s2 * (n2 + 3*n - 6 - (n2 - n +2) * k ))
+        C = s02 * (n2 - 3 - (n-1)**2 * k)
+        vc_rand = (A-B+C) / (n * (n-2) * (n-3)*s02)
         vc_norm = ((1 / (2 * (n + 1) * s02)) *
                    ((2 * s1 + s2) * (n - 1) - 4 * s02))
 
