@@ -165,7 +165,7 @@ class Moran(object):
 
         if permutations:
             sim = [self.__calc(np.random.permutation(self.z))
-                   for i in xrange(permutations)]
+                   for i in range(permutations)]
             self.sim = sim = np.array(sim)
             above = sim >= self.I
             larger = above.sum()
@@ -381,7 +381,7 @@ class Moran_BV(object):
         self.I = self.__calc(zy)
         if permutations:
             nrp = np.random.permutation
-            sim = [self.__calc(nrp(zy)) for i in xrange(permutations)]
+            sim = [self.__calc(nrp(zy)) for i in range(permutations)]
             self.sim = sim = np.array(sim)
             above = sim >= self.I
             larger = above.sum()
@@ -512,7 +512,7 @@ def Moran_BV_matrix(variables, w, permutations=0, varnames=None):
     """
 
     k = len(variables)
-    rk = range(0, k - 1)
+    rk = list(range(0, k - 1))
     results = {}
     for i in rk:
         for j in range(i + 1, k):
@@ -711,7 +711,7 @@ class Moran_Rate(Moran):
                  for e,pop,adj in zip(events, populations, adjusted)]
         names = ['-'.join((e,p)) for e,p in zip(events, populations)]
         out_df = df.copy()
-        rate_df = out_df.from_items(zip(names, rates)) #trick to avoid importing pandas
+        rate_df = out_df.from_items(list(zip(names, rates))) #trick to avoid importing pandas
         stat_df = _univariate_handler(rate_df, names, w=w, inplace=False, 
                                       pvalue = pvalue, outvals = outvals, 
                                       swapname=swapname, 
@@ -726,10 +726,10 @@ class Moran_Local(object):
 
     Parameters
     ----------
-    y : array
-        (n,1), attribute array
-    w : W
-        weight instance assumed to be aligned with y
+    y              : array
+                     (n,1), attribute array
+    w              : W
+                     weight instance assumed to be aligned with y
     transformation : {'R', 'B', 'D', 'U', 'V'}
                      weights transformation,  default is row-standardized "r".
                      Other options include
@@ -871,7 +871,7 @@ class Moran_Local(object):
         z = self.z
         lisas = np.zeros((self.n, self.permutations))
         n_1 = self.n - 1
-        prange = range(self.permutations)
+        prange = list(range(self.permutations))
         k = self.w.max_neighbors + 1
         nn = self.n - 1
         rids = np.array([np.random.permutation(nn)[0:k] for i in prange])
@@ -880,7 +880,7 @@ class Moran_Local(object):
         w = [self.w.weights[ido[i]] for i in ids]
         wc = [self.w.cardinalities[ido[i]] for i in ids]
 
-        for i in xrange(self.w.n):
+        for i in range(self.w.n):
             idsi = ids[ids != i]
             np.random.shuffle(idsi)
             tmp = z[idsi[rids[:, 0:wc[i]]]]
@@ -952,12 +952,12 @@ class Moran_Local_BV(object):
 
     Parameters
     ----------
-    x : array
-        x-axis variable
-    y : array
-        (n,1), wy will be on y axis
-    w : W
-        weight instance assumed to be aligned with y
+    x              : array
+                     x-axis variable
+    y              : array
+                     (n,1), wy will be on y axis
+    w              : W
+                     weight instance assumed to be aligned with y
     transformation : {'R', 'B', 'D', 'U', 'V'}
                      weights transformation,  default is row-standardized "r".
                      Other options include
@@ -1108,7 +1108,7 @@ class Moran_Local_BV(object):
         """
         lisas = np.zeros((self.n, self.permutations))
         n_1 = self.n - 1
-        prange = range(self.permutations)
+        prange = list(range(self.permutations))
         k = self.w.max_neighbors + 1
         nn = self.n - 1
         rids = np.array([np.random.permutation(nn)[0:k] for i in prange])
@@ -1119,7 +1119,7 @@ class Moran_Local_BV(object):
 
         zx = self.zx
         zy = self.zy
-        for i in xrange(self.w.n):
+        for i in range(self.w.n):
             idsi = ids[ids != i]
             np.random.shuffle(idsi)
             tmp = zy[idsi[rids[:, 0:wc[i]]]]
@@ -1197,15 +1197,15 @@ class Moran_Local_Rate(Moran_Local):
 
     Parameters
     ----------
-    e : array
-        (n,1), an event variable across n spatial units
-    b : array
-        (n,1), a population-at-risk variable across n spatial units
-    w : W
-        weight instance assumed to be aligned with y
-    adjusted : boolean
-              whether or not local Moran statistics need to be adjusted for
-              rate variable
+    e              : array
+                     (n,1), an event variable across n spatial units
+    b              : array
+                     (n,1), a population-at-risk variable across n spatial units
+    w              : W
+                     weight instance assumed to be aligned with y
+    adjusted       : boolean
+                     whether or not local Moran statistics need to be adjusted for
+                     rate variable
     transformation : {'R', 'B', 'D', 'U', 'V'}
                      weights transformation,  default is row-standardized "r".
                      Other options include
@@ -1222,47 +1222,47 @@ class Moran_Local_Rate(Moran_Local):
                      If False use PySAL Scheme: HH=1, LH=2, LL=3, HL=4
     Attributes
     ----------
-    y            : array
-                   rate variables computed from parameters e and b
-                   if adjusted is True, y is standardized rates
-                   otherwise, y is raw rates
-    w            : W
-                   original w object
-    permutations : int
-                   number of random permutations for calculation of pseudo
-                   p_values
-    I            : float
-                   value of Moran's I
-    q            : array
-                   (if permutations>0)
-                   values indicate quandrant location 1 HH,  2 LH,  3 LL,  4 HL
-    sim          : array
-                   (if permutations>0)
-                   vector of I values for permuted samples
-    p_sim        : array
-                   (if permutations>0)
-                   p-value based on permutations (one-sided)
-                   null: spatial randomness
-                   alternative: the observed Ii is further away or extreme
-                   from the median of simulated Iis. It is either extremely
-                   high or extremely low in the distribution of simulated Is
-    EI_sim       : float
-                   (if permutations>0)
-                   average value of I from permutations
-    VI_sim       : float
-                   (if permutations>0)
-                   variance of I from permutations
-    seI_sim      : float
-                   (if permutations>0)
-                   standard deviation of I under permutations.
-    z_sim        : float
-                   (if permutations>0)
-                   standardized I based on permutations
-    p_z_sim      : float
-                   (if permutations>0)
-                   p-value based on standard normal approximation from
-                   permutations (one-sided)
-                   for two-sided tests, these values should be multiplied by 2
+    y              : array
+                     rate variables computed from parameters e and b
+                     if adjusted is True, y is standardized rates
+                     otherwise, y is raw rates
+    w              : W
+                     original w object
+    permutations   : int
+                     number of random permutations for calculation of pseudo
+                     p_values
+    Is             : float
+                     local Moran's I values for rates or Empirical Bayes Index
+    q              : array
+                     (if permutations>0)
+                     values indicate quandrant location 1 HH,  2 LH,  3 LL,  4 HL
+    sim            : array
+                     (if permutations>0)
+                     vector of I values for permuted samples
+    p_sim          : array
+                     (if permutations>0)
+                     p-values based on permutations (one-sided)
+                     null: spatial randomness
+                     alternative: the observed Ii is further away or extreme
+                     from the median of simulated values. It is either extremelyi
+                     high or extremely low in the distribution of simulated Is.
+    EI_sim         : array
+                     (if permutations>0)
+                     average values of local Is from permutations
+    VI_sim         : array
+                     (if permutations>0)
+                     variance of Is from permutations
+    seI_sim        : array
+                     (if permutations>0)
+                     standard deviations of Is under permutations.
+    z_sim          : arrray
+                     (if permutations>0)
+                     standardized Is based on permutations
+    p_z_sim        : array
+                     (if permutations>0)
+                     p-values based on standard normal approximation from
+                     permutations (one-sided)
+                     for two-sided tests, these values should be multiplied by 2
 
     Examples
     --------
@@ -1377,7 +1377,7 @@ class Moran_Local_Rate(Moran_Local):
                  for e,pop,adj in zip(events, populations, adjusted)]
         names = ['-'.join((e,p)) for e,p in zip(events, populations)]
         out_df = df.copy()
-        rate_df = out_df.from_items(zip(names, rates)) #trick to avoid importing pandas
+        rate_df = out_df.from_items(list(zip(names, rates))) #trick to avoid importing pandas
         _univariate_handler(rate_df, names, w=w, inplace=True, 
                                       pvalue = pvalue, outvals = outvals, 
                                       swapname=swapname,
