@@ -1,4 +1,4 @@
-from __future__ import division
+
 """
 Apply smoothing to rate computation
 
@@ -23,6 +23,7 @@ from ..cg import get_angle_between, get_points_dist, get_segment_point_dist,\
 from ..common import np, KDTree, requires as _requires
 from ..weights.spatial_lag import lag_spatial as slag
 from scipy.stats import gamma, norm, chi2, poisson
+from functools import reduce
 
 __all__ = ['Excess_Risk', 'Empirical_Bayes', 'Spatial_Empirical_Bayes', 'Spatial_Rate', 'Kernel_Smoother', 'Age_Adjusted_Smoother', 'Disk_Smoother', 'Spatial_Median_Rate', 'Spatial_Filtering', 'Headbanging_Triples', 'Headbanging_Median_Rate', 'flatten', 'weighted_median', 'sum_by_n', 'crude_age_standardization', 'direct_age_standardization', 'indirect_age_standardization', 'standardized_mortality_ratio', 'choynowski', 'assuncao_rate']
 
@@ -101,7 +102,7 @@ def weighted_median(d, w):
 
     """
     dtype = [('w', '%s' % w.dtype), ('v', '%s' % d.dtype)]
-    d_w = np.array(zip(w, d), dtype=dtype)
+    d_w = np.array(list(zip(w, d)), dtype=dtype)
     d_w.sort(order='v')
     reordered_w = d_w['w'].cumsum()
     cumsum_threshold = reordered_w[-1] * 1.0 / 2
@@ -370,7 +371,7 @@ def indirect_age_standardization(e, b, s_e, s_b, n, alpha=0.05):
     log_smr_upper = log_smr + norm_thres * log_smr_sd
     smr_lower = np.exp(log_smr_lower) * s_r_all
     smr_upper = np.exp(log_smr_upper) * s_r_all
-    res = zip(adjusted_r, smr_lower, smr_upper)
+    res = list(zip(adjusted_r, smr_lower, smr_upper))
     return res
 
 
@@ -510,10 +511,10 @@ def assuncao_rate(e, b):
 
     Parameters
     ----------
-    e          : array(n, 1)
-                 event variable measured at n spatial units
-    b          : array(n, 1)
-                 population at risk variable measured at n spatial units
+    e          : array
+                 (n, 1), event variable measured at n spatial units
+    b          : array
+                 (n, 1), population at risk variable measured at n spatial units
 
     Notes
     -----
@@ -521,7 +522,8 @@ def assuncao_rate(e, b):
 
     Returns
     -------
-               : array (nx1)
+               : array
+                 (n,1)
 
     Examples
     --------
@@ -540,7 +542,7 @@ def assuncao_rate(e, b):
     Computing the rates
 
     >>> print assuncao_rate(e, b)[:4]
-    [ 1.04319254 -0.04117865 -0.56539054 -1.73762547]
+    [ 1.03843594 -0.04099089 -0.56250375 -1.73061861]
 
     """
 
@@ -667,15 +669,15 @@ class Empirical_Bayes(_Smoother):
 
     Parameters
     ----------
-    e           : array (n, 1)
-                  event variable measured across n spatial units
-    b           : array (n, 1)
-                  population at risk variable measured across n spatial units
+    e           : array
+                  (n, 1), event variable measured across n spatial units
+    b           : array
+                  (n, 1), population at risk variable measured across n spatial units
 
     Attributes
     ----------
-    r           : array (n, 1)
-                  rate values from Empirical Bayes Smoothing
+    r           : array
+                  (n, 1), rate values from Empirical Bayes Smoothing
 
     Examples
     --------
@@ -859,7 +861,7 @@ class Spatial_Empirical_Bayes(_Spatial_Smoother):
         ngh_num = np.ones_like(e)
         bi = slag(w, b) + b
         for i, idv in enumerate(w.id_order):
-            ngh = w[idv].keys() + [idv]
+            ngh = list(w[idv].keys()) + [idv]
             nghi = [w.id2i[k] for k in ngh]
             ngh_num[i] = len(nghi)
             v = sum(np.square(rate[nghi] - r_mean[i]) * b[nghi])
@@ -1158,7 +1160,7 @@ class Age_Adjusted_Smoother(_Spatial_Smoother):
             max_len = 0 if len(this_r) > max_len else max_len
             rdf.append((outcol, this_r.tolist()))
         padded = (r[1] + [None] * max_len for r in rdf)
-        rdf = zip((r[0] for r in rdf), padded)
+        rdf = list(zip((r[0] for r in rdf), padded))
         rdf = pd.DataFrame.from_items(rdf)
         return rdf
 
@@ -1450,7 +1452,7 @@ class Spatial_Filtering(_Smoother):
         y_range = bbox[1][1] - bbox[0][1]
         x, y = np.mgrid[bbox[0][0]:bbox[1][0]:float(x_range) / x_grid,
                         bbox[0][1]:bbox[1][1]:float(y_range) / y_grid]
-        self.grid = zip(x.ravel(), y.ravel())
+        self.grid = list(zip(x.ravel(), y.ravel()))
         self.r = []
         if r is None and pop is None:
             raise ValueError("Either r or pop should not be None")
@@ -1665,7 +1667,7 @@ class Headbanging_Triples(object):
     (0.33753, 0.302707)
     """
     def __init__(self, data, w, k=5, t=3, angle=135.0, edgecor=False):
-        raise DepricationWarning('Depricated')
+        raise DeprecationWarning('Deprecated. This function is no longer supported.')
         if k < 3:
             raise ValueError("w should be NeareastNeighbors instance & the number of neighbors should be more than 3.")
         if not w.id_order_set:
@@ -1673,39 +1675,39 @@ class Headbanging_Triples(object):
         self.triples, points = {}, {}
         for i, pnt in enumerate(data):
             ng = w.neighbor_offsets[i]
-            points[(i, Point(pnt))] = dict(zip(ng, [Point(d)
-                                                    for d in data[ng]]))
-        for i, pnt in points.keys():
+            points[(i, Point(pnt))] = dict(list(zip(ng, [Point(d)
+                                                    for d in data[ng]])))
+        for i, pnt in list(points.keys()):
             ng = points[(i, pnt)]
             tr, tr_dis = {}, []
-            for c in comb(ng.keys(), 2):
+            for c in comb(list(ng.keys()), 2):
                 p2, p3 = ng[c[0]], ng[c[-1]]
                 ang = get_angle_between(Ray(pnt, p2), Ray(pnt, p3))
                 if ang > angle or (ang < 0.0 and ang + 360 > angle):
                     tr[tuple(c)] = (p2, p3)
             if len(tr) > t:
-                for c in tr.keys():
+                for c in list(tr.keys()):
                     p2, p3 = tr[c]
                     tr_dis.append((get_segment_point_dist(
                         LineSegment(p2, p3), pnt), c))
                 tr_dis = sorted(tr_dis)[:t]
                 self.triples[i] = [trp for dis, trp in tr_dis]
             else:
-                self.triples[i] = tr.keys()
+                self.triples[i] = list(tr.keys())
         if edgecor:
             self.extra = {}
-            ps = dict([(p, i) for i, p in points.keys()])
-            chull = convex_hull(ps.keys())
+            ps = dict([(p, i) for i, p in list(points.keys())])
+            chull = convex_hull(list(ps.keys()))
             chull = [p for p in chull if len(self.triples[ps[p]]) == 0]
             for point in chull:
                 key = (ps[point], point)
                 ng = points[key]
-                ng_dist = [(get_points_dist(point, p), p) for p in ng.values()]
+                ng_dist = [(get_points_dist(point, p), p) for p in list(ng.values())]
                 ng_dist_s = sorted(ng_dist, reverse=True)
                 extra = None
                 while extra is None and len(ng_dist_s) > 0:
                     p2 = ng_dist_s.pop()[-1]
-                    p3s = ng.values()
+                    p3s = list(ng.values())
                     p3s.remove(p2)
                     for p3 in p3s:
                         dist_p2_p3 = get_points_dist(p2, p3)
@@ -1811,7 +1813,7 @@ class Headbanging_Median_Rate(object):
     array([ 0.00091659,  0.        ,  0.00156838,  0.0018315 ,  0.00498891])
     """
     def __init__(self, e, b, t, aw=None, iteration=1):
-        warnings.warn("Deprecated", DepricationWarning)
+        raise DeprecationWarning('Deprecated. This function is no longer supported.')
         self.r = e * 1.0 / b
         self.tr, self.aw = t.triples, aw
         if hasattr(t, 'extra'):
@@ -1854,7 +1856,7 @@ class Headbanging_Median_Rate(object):
                 trp_r = r[list(trp)]
                 dtype = [('r', '%s' % trp_r.dtype), ('w',
                                                      '%s' % self.aw.dtype)]
-                trp_r = np.array(zip(trp_r, list(trp)), dtype=dtype)
+                trp_r = np.array(list(zip(trp_r, list(trp))), dtype=dtype)
                 trp_r.sort(order='r')
                 lowest.append(trp_r['r'][0])
                 highest.append(trp_r['r'][-1])
@@ -1885,7 +1887,7 @@ class Headbanging_Median_Rate(object):
     def __search_headbanging_median(self):
         r, tr = self.r, self.tr
         new_r = []
-        for k in tr.keys():
+        for k in list(tr.keys()):
             screens = self.__get_screens(
                 k, tr[k], weighted=(self.aw is not None))
             new_r.append(self.__get_median_from_screens(screens))
