@@ -1,6 +1,6 @@
-from collections import OrderedDict
-import math
-import operator
+#from collections import OrderedDict
+#import math
+#import operator
 import pysal as ps
 import numpy as np
 
@@ -19,9 +19,13 @@ def compute_length(v0, v1):
     --------
     Euclidean distance
     """
-
-    return math.sqrt((v0[0] - v1[0])**2 + (v0[1] - v1[1])**2)
-
+    #  Is there a reason we are using `math` as opposed to `numpy` is this function?
+    #  Moreover, we are not using `OrderedDict` or `operator` for anything currently in
+    #  any of the defined functions in `utils.py`. 
+    
+    #return math.sqrt((v0[0] - v1[0])**2 + (v0[1] - v1[1])**2)
+    return np.sqrt((v0[0] - v1[0])**2 + (v0[1] - v1[1])**2)
+    
 
 def get_neighbor_distances(ntw, v0, l):
     edges = ntw.enum_links_node(v0)
@@ -109,6 +113,40 @@ def dijkstra(ntw, cost, node, n=float('inf')):
     return distance, np.array(pred, dtype=np.int)
 
 
+def dijkstra_mp(xxx_todo_changeme):
+    """
+    Compute the shortest path between a start node and all other nodes in the web 
+    utilizing multiple cores upon request.
+    
+    Parameters
+    ----------
+    ntw:        object
+                PySAL network object
+                
+    cost:       dict
+                key:    tuple
+                        (start node, end node)
+                value:  float
+                        Cost per edge to travel, e.g. distance
+    
+    node:       int
+                Start node ID
+    
+    n:          float('inf')
+                integer break point to stop iteration and return n neighbors
+    
+    Returns
+    -------
+    distance:   list
+                List of distances from node to all other nodes.
+    
+    pred:       list
+                List of preceeding nodes for traversal route.
+    """
+    (ntw, cost, node) = xxx_todo_changeme
+    return dijkstra(ntw, cost, node)
+       
+    
 def squaredDistancePointSegment(point, segment):
     """Find the squared distance between a point and a segment
     
