@@ -762,6 +762,8 @@ class DistanceBand(W):
         See detail in pysal issue #126.
 
         """
+        if ids is not None:
+            ids=list(ids)
         self.p = p
         self.threshold = threshold
         self.binary = binary
@@ -857,6 +859,8 @@ class DistanceBand(W):
             ids = df.index.tolist()
         elif isinstance(ids, str):
             ids = df[ids].tolist()
+        else:
+            ids = df.index.tolist()
         return cls(pts, threshold, ids=ids, **kwargs)
 
     def _band(self):
@@ -878,7 +882,7 @@ class DistanceBand(W):
         if self.binary:
             self.dmat[self.dmat>0] = 1
             self.dmat.eliminate_zeros()
-            tempW = WSP2W(WSP(self.dmat), silent_island_warning=self.silent)
+            tempW = WSP2W(WSP(self.dmat, id_order=ids), silent_island_warning=self.silent)
             neighbors = tempW.neighbors
             weight_keys = list(tempW.weights.keys())
             weight_vals = list(tempW.weights.values())
@@ -888,7 +892,7 @@ class DistanceBand(W):
             weighted = self.dmat.power(self.alpha)
             weighted[weighted==np.inf] = 0
             weighted.eliminate_zeros()
-            tempW = WSP2W(WSP(weighted), silent_island_warning=self.silent)
+            tempW = WSP2W(WSP(weighted, id_order=ids), silent_island_warning=self.silent)
             neighbors = tempW.neighbors
             weight_keys = list(tempW.weights.keys())
             weight_vals = list(tempW.weights.values())
